.. _github-stats-3-7-2:

GitHub statistics for 3.7.2 (Jul 05, 2023)
==========================================

GitHub statistics for 2023/03/04 (tag: v3.7.1) - 2023/07/05

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 36 issues and merged 156 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/81?closed=1>`__

The following 25 authors contributed 248 commits.

* Adam J. Stewart
* Antony Lee
* Astra
* Daniele Nicolodi
* daniilS
* dependabot[bot]
* Elliott Sales de Andrade
* Greg Lucas
* Jody Klymak
* Kyle Sunden
* MeeseeksMachine
* Melissa Weber Mendonça
* Mubin Manasia
* NISHANT KUMAR
* Oscar Gustafsson
* Petros Tzathas
* Ruth Comer
* Scott Shambaugh
* Smeet nagda
* SnorfYang
* Stefanie Molin
* Steffen Rehberg
* Thomas A Caswell
* Tim Hoffmann
* Yi Wei

GitHub issues and pull requests:

Pull Requests (156):

* :ghpull:`26260`: Backport PR #25960 on branch v3.7.x (FIX: wspace and hspace in subfigures without layout engine)
* :ghpull:`25960`: FIX: wspace and hspace in subfigures without layout engine
* :ghpull:`26238`: Backport PR #26237 on branch v3.7.x (Update FancyBboxPatch docstring)
* :ghpull:`26234`: Backport PR #26232 on branch v3.7.x (FIX: pcolor writing to read-only input mask)
* :ghpull:`26232`: FIX: pcolor writing to read-only input mask
* :ghpull:`26229`: Backport PR #26223 on branch v3.7.x (Fix: pcolormesh writing to read-only input mask)
* :ghpull:`26227`: Backport PR #26184 on branch v3.7.x (FIX: AnnotationBbox extents before draw)
* :ghpull:`26223`: Fix: pcolormesh writing to read-only input mask
* :ghpull:`26184`: FIX: AnnotationBbox extents before draw
* :ghpull:`26214`: Auto backport of pr 26186 on v3.7.x
* :ghpull:`26216`: Backport PR #26126 on branch v3.7.x (Revert "Merge pull request #24555 from parthpankajtiwary/symlog-warn")
* :ghpull:`26215`: Backport PR #25824 on branch v3.7.x (pdf: Use explicit palette when saving indexed images)
* :ghpull:`26211`: Backport PR #25704 on branch v3.7.x (FIX: don't round image sizes to pixel if meant to be unsampled)
* :ghpull:`26186`: [Doc] Improve documentation types
* :ghpull:`26177`: Backport PR #26154 on branch v3.7.x (MNT: py312 deprecates pickling objects in itertools)
* :ghpull:`26154`: MNT: py312 deprecates pickling objects in itertools
* :ghpull:`26175`: Backport PR #26165 on branch v3.7.x (Avoid Py_VerboseFlag deprecation from Python 3.12)
* :ghpull:`26165`: Avoid Py_VerboseFlag deprecation from Python 3.12
* :ghpull:`26136`: Backport PR #26135 on branch v3.7.x (TST: xfail Tk test on Python 3.9 Azure macOS also)
* :ghpull:`26158`: Backport PR #26153 on branch v3.7.x (Restrict pyparsing version)
* :ghpull:`26153`: Restrict pyparsing version
* :ghpull:`26149`: Backport PR #26148 on branch v3.7.x (Clarify how to get data from Line3D and fix formatting issue)
* :ghpull:`26148`: Clarify how to get data from Line3D and fix formatting issue
* :ghpull:`26135`: TST: xfail Tk test on Python 3.9 Azure macOS also
* :ghpull:`26133`: Backport PR #26084 on branch v3.7.x (added note about python 3 to venv)
* :ghpull:`26126`: Revert "Merge pull request #24555 from parthpankajtiwary/symlog-warn"
* :ghpull:`26127`: Backport PR #25068 on branch v3.7.x (Fix pgf tests with TeXLive 2022)
* :ghpull:`25068`: Fix pgf tests with TeXLive 2022
* :ghpull:`25824`: pdf: Use explicit palette when saving indexed images
* :ghpull:`26116`: Backport PR #26006 on branch v3.7.x (DOC: Use scientific-python-nightly-wheels for nightly build index)
* :ghpull:`26055`: Backport PR #26052 on branch v3.7.x (Improve Qt compatibility)
* :ghpull:`26053`: Backport PR #25858 on branch v3.7.x (Get dlerror() immediately after dlclose() fails.)
* :ghpull:`26052`: Improve Qt compatibility
* :ghpull:`25858`: Get dlerror() immediately after dlclose() fails.
* :ghpull:`26048`: Backport PR #26044 on branch v3.7.x (DOC: add steering council email to triage page + remove unactionable instructions)
* :ghpull:`26039`: Backport PR #26038 on branch v3.7.x (subsubsection titles for backend tables)
* :ghpull:`26034`: ci: Skip PySide6 6.5.1 on another environment
* :ghpull:`26019`: Backport PR #25985 on branch v3.7.x (Drop metadata table when subsetting fonts)
* :ghpull:`26009`: Backport PR #25978 on branch v3.7.x (Fix subslice optimization for long, fully nan lines.)
* :ghpull:`26021`: Backport PR #26005 on branch v3.7.x (Fix backend tests on CI)
* :ghpull:`25985`: Drop metadata table when subsetting fonts
* :ghpull:`25978`: Fix subslice optimization for long, fully nan lines.
* :ghpull:`26002`: Bump pypa/cibuildwheel from 2.12.3 to 2.13.0
* :ghpull:`26005`: Fix backend tests on CI
* :ghpull:`26001`: Backport PR #25954 on branch v3.7.x (Add note that subfigure is still provisional to docstring)
* :ghpull:`25954`: Add note that subfigure is still provisional to docstring
* :ghpull:`25996`: Backport PR #25992 on branch v3.7.x (Document that GridSpec.get_subplot_params ignores gridspec.figure.)
* :ghpull:`25992`: Document that GridSpec.get_subplot_params ignores gridspec.figure.
* :ghpull:`25984`: Backport PR #25982 on branch v3.7.x (Doc: Updates default value for nonpositve parameter for semilogx and semilogy)
* :ghpull:`25982`: Doc: Updates default value for nonpositve parameter for semilogx and semilogy
* :ghpull:`25975`: Backport PR #25964 on branch v3.7.x (Fix get_constrained_layout_pads)
* :ghpull:`25980`: Backport PR #25977 on branch v3.7.x ([Doc]: Fix navigation sidebar for Animation examples)
* :ghpull:`25976`: Backport PR #25973 on branch v3.7.x (Add setuptools as an explicit build requirement)
* :ghpull:`25973`: Add setuptools as an explicit build requirement
* :ghpull:`25964`: Fix get_constrained_layout_pads
* :ghpull:`25972`: Backport PR #25918 on branch v3.7.x (migrate from utcfromtimestamp to fromtimestamp)
* :ghpull:`25959`: Backport PR #25955 on branch v3.7.x (Update performance note of hist() to mention stairs().)
* :ghpull:`25957`: Backport PR #25956 on branch v3.7.x (Reverse stackplot legend to match data display)
* :ghpull:`25955`: Update performance note of hist() to mention stairs().
* :ghpull:`25918`: migrate from utcfromtimestamp to fromtimestamp
* :ghpull:`25943`: Backport PR #25902 on branch v3.7.x (Fix TransformedBbox.{,full_}contains.)
* :ghpull:`25902`: Fix TransformedBbox.{,full_}contains.
* :ghpull:`25928`: Backport PR #25920 on branch v3.7.x (Rewrite offset_copy for better error message)
* :ghpull:`25935`: Backport PR #25934 on branch v3.7.x (DOC: Fix figure annotation example)
* :ghpull:`25931`: Backport PR #25929 on branch v3.7.x (changed incubator invite channel link to community channel)
* :ghpull:`25920`: Rewrite offset_copy for better error message
* :ghpull:`25898`: Backport PR #25897 on branch v3.7.x (Fix typo of missing quote in core font docs)
* :ghpull:`25893`: Backport PR #25792 on branch v3.7.x (Fix broken symlinks for expected images on WSL)
* :ghpull:`25792`: Fix broken symlinks for expected images on WSL
* :ghpull:`25892`: Backport PR #25832 on branch v3.7.x ([BUG] Prevent under the hood downcasting of values)
* :ghpull:`25873`: DOC: clarify how colorbar steals space
* :ghpull:`25832`: [BUG] Prevent under the hood downcasting of values
* :ghpull:`25877`: Backport PR #25874 on branch v3.7.x (Tweak demo_edge_colorbar.)
* :ghpull:`25879`: Backport PR #25547 on branch v3.7.x (FIX: ``_safe_first_finite`` on all non-finite array)
* :ghpull:`25875`: Backport PR #25868 on branch v3.7.x (TST: Add test for layoutgrid memory leak)
* :ghpull:`25547`: FIX: ``_safe_first_finite`` on all non-finite array
* :ghpull:`25868`: TST: Add test for layoutgrid memory leak
* :ghpull:`25865`: Backport PR #25853 on branch v3.7.x (Fix LayoutGrid leaks)
* :ghpull:`25853`: Fix LayoutGrid leaks
* :ghpull:`25842`: Backport PR #25840 on branch v3.7.x (Emit explanatory exception when no temporary cachedir can be created.)
* :ghpull:`25840`: Emit explanatory exception when no temporary cachedir can be created.
* :ghpull:`25827`: Backport PR #25813 on branch v3.7.x ([TST] Adjust tests to be more tolerant to floating point math operations being imprecise)
* :ghpull:`25813`: [TST] Adjust tests to be more tolerant to floating point math operations being imprecise
* :ghpull:`25808`: Backport PR #25214 on branch v3.7.x (DOC: Add section on how to start contributing)
* :ghpull:`25802`: Backport PR #25797 on branch v3.7.x (Replace random values by hard-coded numbers in plot-types ...)
* :ghpull:`25778`: Backport PR #25776 on branch v3.7.x (Doc : Updates default value for nonpositve parameter)
* :ghpull:`25776`: Doc : Updates default value for nonpositve parameter
* :ghpull:`25704`: FIX: don't round image sizes to pixel if meant to be unsampled
* :ghpull:`25761`: Backport PR #25760 on branch v3.7.x (unbreak doc build with Sphinx 6.2)
* :ghpull:`25754`: Backport PR #25727 on branch v3.7.x (Doc: Replace matplotlibrc.template)
* :ghpull:`25727`: Doc: Replace matplotlibrc.template
* :ghpull:`25750`: Backport PR #25733 on branch v3.7.x (Add tests for missing text wrap cases)
* :ghpull:`25733`: Add tests for missing text wrap cases
* :ghpull:`25740`: Backport PR #25736 on branch v3.7.x (added assigning and duplicating section heading to contribute guide)
* :ghpull:`25705`: Backport PR #25681 on branch v3.7.x (BUG: Return null Bbox when there is no intersection for bar_label center.)
* :ghpull:`25700`: Backport PR #25693 on branch v3.7.x (Correctly hide download buttons using CSS)
* :ghpull:`25681`: BUG: Return null Bbox when there is no intersection for bar_label center.
* :ghpull:`25665`: Backport PR #25663 on branch v3.7.x (Don't use deprecated cm.get_cmap in qt figureoptions.)
* :ghpull:`25666`: Backport PR #25658 on branch v3.7.x (TST: Bump exclude for newly released nbconvert)
* :ghpull:`25663`: Don't use deprecated cm.get_cmap in qt figureoptions.
* :ghpull:`25658`: TST: Bump exclude for newly released nbconvert
* :ghpull:`25630`: Backport PR #25481 on branch v3.7.x (Fix 3D set_aspect error cases)
* :ghpull:`25637`: Backport PR #25636 on branch v3.7.x (Ensure ImportError's have a message)
* :ghpull:`25636`: Ensure ImportError's have a message
* :ghpull:`25629`: Backport PR #25616 on branch v3.7.x (broken_barh: fix docstring typo)
* :ghpull:`25481`: Fix 3D set_aspect error cases
* :ghpull:`25616`: broken_barh: fix docstring typo
* :ghpull:`25626`: Backport PR #25624 on branch v3.7.x (FIX: correctly unset the layout engine in Figure.tight_layout)
* :ghpull:`25620`: Backport PR #25615 on branch v3.7.x (TST: Avoid broken nbconvert)
* :ghpull:`25624`: FIX: correctly unset the layout engine in Figure.tight_layout
* :ghpull:`25621`: Backport PR #25619 on branch v3.7.x (TST: Unbreak pyside65 by installing libxcb-cursor0)
* :ghpull:`25619`: TST: Unbreak pyside65 by installing libxcb-cursor0
* :ghpull:`25615`: TST: Avoid broken nbconvert
* :ghpull:`25589`: Backport PR #25585 on branch v3.7.x (DOC: improve interpolation kwarg doc in imshow [ci doc])
* :ghpull:`25585`: DOC: improve interpolation kwarg doc in imshow [ci doc]
* :ghpull:`25581`: Backport PR #25580 on branch v3.7.x (Fix return type of get_plot_commands)
* :ghpull:`25580`: Fix return type of get_plot_commands
* :ghpull:`25578`: Backport PR #25574 on branch v3.7.x (DOC: Added exported colors to colors.api)
* :ghpull:`25535`: Backport PR #25518 on branch v3.7.x (DOC: Fix the bars having numeric value of cm but labeled as inches)
* :ghpull:`25530`: Backport PR #25508 on branch v3.7.x (DOC: Fix thumbnail title for sphinx gallery)
* :ghpull:`25528`: Backport PR #25519 on branch v3.7.x (Fix typo in Quick start guide tutorial)
* :ghpull:`25525`: Backport PR #25524 on branch v3.7.x (Add ipykernel as an explicit doc dependency)
* :ghpull:`25520`: Backport PR #25499: FIX: use locators in adjust_bbox
* :ghpull:`25516`: Backport PR #25494 on branch v3.7.x (Ignore errors loading artifacts from CircleCI)
* :ghpull:`25499`: FIX: use locators in adjust_bbox
* :ghpull:`25512`: Backport PR #25496 on branch v3.7.x (BUG: fix IPython's %pylab mode detection)
* :ghpull:`25496`: BUG: fix IPython's %pylab mode detection
* :ghpull:`25503`: Backport PR #25495 on branch v3.7.x (DOC: Clarify note in get_path_collection_extents)
* :ghpull:`25495`: DOC: Clarify note in get_path_collection_extents
* :ghpull:`25490`: Backport PR #25486 on branch v3.7.x (DOC: remove rcdefaults from barh example)
* :ghpull:`25480`: Backport PR #25476 on branch v3.7.x (DOC: Fix docstring formatting)
* :ghpull:`25476`: DOC: Fix docstring formatting
* :ghpull:`25474`: Backport PR #25470 on branch v3.7.x (FIX: do not cache exceptions)
* :ghpull:`25470`: FIX: do not cache exceptions
* :ghpull:`25465`: Backport PR #25442 on branch v3.7.x (Fix disconnection of callbacks when draggable artist is deparented.)
* :ghpull:`25462`: Backport PR #25461 on branch v3.7.x (Fix issue #25458 by changing "normed" to "density" in documentation)
* :ghpull:`25442`: Fix disconnection of callbacks when draggable artist is deparented.
* :ghpull:`25459`: Backport PR #25457 on branch v3.7.x (Add references to backend_{gtk3,gtk4,wx} in docs.)
* :ghpull:`25452`: Backport PR #25449 on branch v3.7.x (Bump pypa/cibuildwheel from 2.12.0 to 2.12.1)
* :ghpull:`25451`: Backport PR #25433 on branch v3.7.x (Release mouse grabs when owning Axes is removed)
* :ghpull:`25449`: Bump pypa/cibuildwheel from 2.12.0 to 2.12.1
* :ghpull:`25433`: Release mouse grabs when owning Axes is removed
* :ghpull:`25450`: Backport PR #25394 on branch v3.7.x ([DOC] Clarify how to change side of the TickedStroke ticks)
* :ghpull:`25394`: [DOC] Clarify how to change side of the TickedStroke ticks
* :ghpull:`25447`: Backport PR #23863 on branch v3.7.x (Add tests for mpl_toolkit anchored artists)
* :ghpull:`23863`: Add tests for mpl_toolkit anchored artists
* :ghpull:`25437`: Backport PR #25435 on branch v3.7.x (TST: unbreak appveyor)
* :ghpull:`25435`: TST: unbreak appveyor
* :ghpull:`25436`: Backport PR #25428 on branch v3.7.x (Fix Legend.set_draggable() with update="bbox")
* :ghpull:`25428`: Fix Legend.set_draggable() with update="bbox"
* :ghpull:`25411`: Backport PR #25409 on branch v3.7.x (Improve/correct documentation)
* :ghpull:`25409`: Improve/correct documentation
* :ghpull:`25402`: Merge v3.7.1-doc into v3.7.x
* :ghpull:`25397`: Backport PR #25384 on branch v3.7.x (FIX: Remove some numpy function overrides from pylab)
* :ghpull:`25384`: FIX: Remove some numpy function overrides from pylab
* :ghpull:`25392`: Backport PR #25388 on branch v3.7.x (Better axis labels for examples)

Issues (36):

* :ghissue:`25511`: [Bug]: wspace and hspace in subfigures not working
* :ghissue:`26230`: [Bug]: pcolor writing to read-only input mask
* :ghissue:`26093`: [Bug]: pcolormesh writing to input mask
* :ghissue:`24453`: [Bug]:  AnnotationBbox does not return correct window_extent before first draw
* :ghissue:`26161`: [MNT]: install on Python 3.12.0b3
* :ghissue:`26146`: Impossible to get the z value of a line in 3D
* :ghissue:`26118`: [Bug]: symlog scale generates false warning when mouse is moved
* :ghissue:`25806`: [Bug]: pdf export for large image sizes results in wrong colors
* :ghissue:`20575`: cm.set_bad() not working for specific values of grayscale and dpi when saving as pdf
* :ghissue:`26054`: [TST] Upcoming dependency test failures
* :ghissue:`24025`: [Bug]: meta tables warn they cannot be subset
* :ghissue:`25988`: [TST] Qt/Pyside 6.5.1 dependency test failures
* :ghissue:`13109`: get_subplot_params behavior doesn't match docstring
* :ghissue:`25963`: [Bug]: fig.get_constrained_layout_pads() raises AttributeError
* :ghissue:`25912`: deal with upcoming deprecations in CPython
* :ghissue:`12057`: TransformedBbox.contains has less-than-optimal semantics
* :ghissue:`24818`: [Bug]: ax.errorbar raises for all-nan data on matplotlib 3.6.2
* :ghissue:`18294`: UserWarning thrown when all values are "bad", but not when only some are
* :ghissue:`25819`: [Bug]: Memory leak in constrained_layout
* :ghissue:`25838`: [Doc]: running matplotlib with readonly fs
* :ghissue:`25826`: [TST] Upcoming dependency test failures
* :ghissue:`25789`: [TST] Upcoming dependency test failures
* :ghissue:`25758`: [Doc]: Default value for nonpositive parameter is not as documented
* :ghissue:`8981`: Incorrect imshow extent in PDF backend
* :ghissue:`25678`: [Doc]: matplotlibrc.template does not exist anymore
* :ghissue:`25625`: [Bug]: RuntimeError when bar_label of stacked bar chart comes to rest outside of plot's Y limit
* :ghissue:`25443`: [Bug]: 3D set_aspect equal doesn't bound data in all cases
* :ghissue:`7805`: tight layout kwargs have no effect if rc autolayout setting is set (MPL 1.5.3)
* :ghissue:`25575`: [Bug]: imshow interpolation='none' ignored when using savefig() to PDF format
* :ghissue:`23884`: [Doc]: Thumbnail title in gallery show rst formatting characters
* :ghissue:`22625`: [Bug]: Setting bbox_inches to a Bbox in fig.savefig resizes colorbar
* :ghissue:`25485`: [Bug]: Main loop integration with IPyhton broken after matplotlib version 3.6.2
* :ghissue:`25440`: [Bug]: Attribute Error combining matplotlib 3.7.1 and mplcursor on data selection
* :ghissue:`25345`: [Bug]: using clf and pyplot.draw in range slider on_changed callback blocks input to widgets
* :ghissue:`25416`: Sphinx-Gallery 0.12 kills AppVeyor tests
* :ghissue:`25379`: [TST] Upcoming dependency test failures
